<?php
/*
Plugin Name: Line In Typography
Plugin URI: http://line-in.co.uk/
Description: Overlays a typographical grid and columns for theme development
Author: Simon Fairbairn
Version: 0.2.1
Requires at least: 3.2
Author URI: http://line-in.co.uk/
License: GPL
*/

define('LIT_Version', '0.2.1');

/**
 *	Imports the required class
 */
include "classes/libc-settings-api-with-page.php"; 
 
/**
 *	Registers the activation/deactivation hooks (static methods)
 */ 

register_activation_hook(__FILE__, array('Line_In_Typography', 'install_plugin' ) );
register_deactivation_hook(__FILE__, array( 'Line_In_Typography', 'uninstall_plugin') );


/**
 * Calls the class on the post edit screen
 */
function call_line_in_typography() 
{
    return new Line_In_Typography();
}
add_action( 'init', 'call_line_in_typography' );


/** 
 * The Class
 */
if ( !class_exists('Line_In_Typography') ) { 
	 
	class Line_In_Typography extends LIPBC_Settings_API_With_Page {
		static 		$add_script;
		protected 	$plugin_url;
		protected 	$plugin_basename;
		public 		$options_name;
		protected 	$parent_page = 'options-general.php';
		protected 	$plugin_id = 'li_typography';
		protected 	$plugin_title = "Line In Typography";
		protected 	$plugin_abbr = "LI Typography";
		protected 	$lang = 'litypography';

		function __construct() {
			// Set up properties
			$this->plugin_basename = plugin_basename( __FILE__ );
			$this->plugin_url = plugins_url( '', __FILE__ ).'/';
			$this->options_name = $this->plugin_id . '_options';

			$this->load_scripts('line-in-typography', array('jquery'), LIT_Version );
			// Call parent's constructor
			parent::__construct( true );
			
			if ( !is_admin() ) {

				// wp_enqueue_style('inline-typography-css', $this->plugin_url . 'inline-typography.css', null, '0.1', 'all' );
				add_action('wp_head', array( &$this, 'head' ) );
				add_action('wp_footer', array( &$this, 'foot' ) );
			} else {
				add_action('admin_menu', array( &$this, 'add_submenu_page' ) );
			}
			
		}
		
		static function install_plugin() {
		
		}
		
		static function uninstall_plugin() {
		
		}
		
		
		/** Settings API options (consider a reusable class situation) */
		
		function get_default_options() {
			$options = array(
				'line-height' 		=> 21,
				'font-size'			=> 14,
				'elements'			=> '.container',
				'paragraph-text'	=> 'Paragraph to test line height',
				'show-paragraph'	=> 'true',
				'background-offset'	=> 0,
				'plugin-version'	=> LIT_Version
			
			);
			return $options;
		}
		
		
		
		function add_settings_section() {
			add_settings_section('li_typography_settings_section', 'General Settings', array( &$this, 'li_typography_settings_section_intro'), $this->plugin_id);
			add_settings_field('li_typography_line_height', 'Set Line Height', array( &$this, 'li_typography_line_height'), $this->plugin_id, 'li_typography_settings_section');
			// add_settings_field('li_typography_font_size', 'Set Font Size', array( &$this, 'li_typography_font_size'), $this->plugin_id, 'li_typography_settings_section');
			add_settings_field('li_typography_elements', 'DOM Elements', array( &$this, 'li_typography_elements'), $this->plugin_id, 'li_typography_settings_section');
			add_settings_field('li_typography_paragraph_text', 'Test Paragraph Text', array( &$this, 'li_typography_paragraph_text'), $this->plugin_id, 'li_typography_settings_section');
			add_settings_field('li_typography_background_offset', 'Lines Offset', array( &$this, 'li_typography_background_offset'), $this->plugin_id, 'li_typography_settings_section');


			add_settings_field('li_typography_show_paragraph', 'Show Test Paragraph', array( &$this, 'li_typography_show_paragraph') , $this->plugin_id, 'li_typography_settings_section');
		}
		
		
		
		function li_typography_settings_section_intro() {
			?>
			 <p><?php _e( 'Manage options for the Line In Typography plugin. Refer to contextual help for more information.', $this->lang ); ?></p>
			<?php
		}
		
		function li_typography_line_Height() {
			?>
			<input type='text' name='<?php echo $this->options_name; ?>[line-height]' value='<?php echo intval($this->options['line-height']); ?>' id='<?php echo $this->options_name; ?>-line-height' size='5' /> <span class='description'>Explicitly set your line height here, or set to 0 to have the plugin try and figure it out from your theme's body styles</span>
			
			<?php
		}
		function li_typography_font_size() {
			?>
			<input type='text' name='<?php echo $this->options_name; ?>[font-size]' value='<?php echo intval($this->options['font-size']); ?>' id='<?php echo $this->options_name; ?>-font-size' size='5' /> <span class='description'>Explicitly set your font size here, or set to 0 to have the plugin try and figure it out from your theme's body styles</span>
			<?php
		}
		function li_typography_elements() {
			?>
			<input type='text' name='<?php echo $this->options_name; ?>[elements]' value='<?php echo esc_attr($this->options['elements']); ?>' id='<?php echo $this->options_name; ?>-elements' /> <span class='description'>Comma separated list of DOM elements to attach the grids to</span>
			<?php
		}
		function li_typography_paragraph_text() {
			?>
			<input type='text' name='<?php echo $this->options_name; ?>[paragraph-text]' value='<?php echo esc_attr($this->options['paragraph-text']); ?>' id='<?php echo $this->options_name; ?>-paragraph-text' size='50' /> <span class='description'>A test paragraph to show above all content. Indicates the correct positioning on the line that all paragraphs should adhere to.</span>
			<?php
		}
						
		
		function li_typography_show_paragraph() {
			?>
			<input type="radio" name="<?php echo $this->options_name; ?>[show-paragraph]" value="true"<?php checked( 'true' == $this->options['show-paragraph'] ); ?> id='<?php echo $this->options_name; ?>-show-paragraph-true' /><label for='<?php echo $this->options_name; ?>-show-paragraph-true'>Yes</label>
			<input type="radio" name="<?php echo $this->options_name; ?>[show-paragraph]" value="false"<?php checked( 'false' == $this->options['show-paragraph'] ); ?> id='<?php echo $this->options_name; ?>-show-paragraph-false' /><label for='<?php echo $this->options_name; ?>-show-paragraph-false'>No</label>
			
			<?php
		}
		function li_typography_background_offset() {
			?>
			<input type='text' name='<?php echo $this->options_name; ?>[background-offset]' value='<?php echo intval( $this->options['background-offset'] ); ?>' id='<?php echo $this->options_name; ?>-background-offset' size='5' /> <span class='description'>Shift the lines up or down to get your test paragraph sitting exactly on them.</span>
			
			<?php
		}
		
		function validate( $input ) {
			$valid_input = $this->options;
			$default_options = $this->get_default_options();
			
			if ( isset( $_POST['reset'] ) ) {
				$input = $this->get_default_options();
				add_settings_error('li_typography_settings_section', 'reset-message', "Options reset to default settings", 'updated');
			} else if ( isset( $_POST['submit'] ) ) {
				$error = false;
				if ( (int) $input['line-height'] < 0 ) {
					$input['line-height'] = $valid_input['line-height'];
					$error[] = "Line height not a valid positive integer, not updated";
				}
//				if ( (int) $input['font-size'] < 0 ) {
//					$input['font-size'] = $valid_input['font-size'];
//					$error[] = "Font size not a valid positive integer, not updated";
//				}
				$input['elements'] = wp_kses($input['elements'], array());
				if ( '' == $input['elements'] ) {
					$input['elements'] = $valid_input['elements'];
					$error[] = "You have not set a valid element to attach the grids to. Setting not updated.";	
					
				}
				
				
				$input['paragraph-text'] = wp_kses($input['paragraph-text'], array());
				$input['show-paragraph'] = ( 'true' == $input['show-paragraph'] ) ? 'true' : 'false';
				if ( 'true' == $input['show-paragraph'] && '' == $input['paragraph-text'] ) {
					$input['paragraph-text'] = $default_options['paragraph-text'];
					$error[] = "If you want to show the paragraph, you'll need some paragraph text. Set to default";
				}
				
				$input['background-offset'] = (int) $input['background-offset'];
				
				
				if ( false !== $error ) {
					$i = 0;
					$output = false;
					foreach ( $error as $err ) {
						
						if ( $i > 0 ) {
							$output .= "<br />";
						}
						$output .= $err;
						$i++;
					
					}
					add_settings_error('li_typography_settings_section', 'error-message', $output, 'error');
					add_settings_error('li_typography_settings_section', 'updated-message', "All other settings updated", 'updated');
				}
			}
			return $input;
		}
	
		
		
		
		/** END SETTINGS API */

		/** Page html */
		
				
		
		
		function head() { 
			self::$add_script = true; 
			
			?>
			<style>
				.gr960-12 {
					background: url(<?php echo $this->plugin_url; ?>css/img/960-12px.png) 0 -4px !important;
					background-size: 100%;
				}
				.gr960-16 {
					background: url(<?php echo $this->plugin_url; ?>css/img/960-16px.png) 0 -4px !important;
					background-size: 100%;
				}
				
				#lit-vertical-rhythm {
					width: 100%;
					z-index: 100;
					position: absolute;
					top: 0;
					left: 0;	
				}
				#lit-buttons {
					position: fixed;
					top: 50px;
					right: 0;
					z-index: 200;
					background: #fff;
					padding: 15px;
					border: 1px solid #000;
					-moz-border-radius: 10px;
					-webkit-border-radius: 10px;
					border-radius: 10px;
					width: 400px;
					
				}
				
				.switchImages embed, .switchImages img, .switchImages object, .switchImages video, .switchImages iframe  {
					display: none !important;	
				}
				
								
				/* =ENDDEL */
				            
            
            </style>
		<?php }
		
		
		function foot() { 
			if ( ! self::$add_script )
				return;
			wp_print_scripts($this->plugin_id . '-scripts'); 
			

			
		?>

			<script>
				/*
				 *	Variables:
				 *
				 *	containers are what the plugin is attached to
				 *
				 *	fontSizeContainer (default: body), for most of my sites it'll be wrap now
				 *	
				 *	Lines offset (default: 0), just in case you need to offset the lines
				 *
				 */
				jQuery(document).ready(function($) {
					var myOptions = {	
						pluginUrl			: "<?php echo $this->plugin_url; ?>",
						lineHeightContainer	: 'body',
						gridState			: 'off',
						lineState			: 'off',
						testHtml			: "<p><?php echo $this->options['paragraph-text']; ?></p>",
						showTestHtml		: '<?php echo $this->options['show-paragraph']; ?>',
						backgroundOffset	: <?php echo $this->options['background-offset']; ?>,
						lineHeight			: <?php echo $this->options['line-height']; ?>
					};
					$('<?php echo $this->options['elements']; ?>' ).LineInTypography(myOptions);
				});
			</script>

		<?php
		}
	}
}
?>